@@ -3,10 +3,10 @@ package Perinci::Role::MetaAccessor;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 requires 'get_meta';
-requires 'get_all_meta';
+requires 'get_all_metas';
 requires 'set_meta';
 
 1;
@@ -21,7 +21,7 @@ Perinci::Role::MetaAccessor - Role for metadata accessor class
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 AUTHOR
 
